2012-12-11 - 0.4.1
##################

- fixed typo


2012-12-11 - 0.4
################

- added inc/decr support
- tweaked the timeout waits
- added and using ReconnectClient to survive servers restarts
- added a retry loop


2012-10-05 - 0.3.1
##################

- fixed cache.clear
- make sure timeout=0 is treated as infinite


2012-10-05 - 0.3
################

- now based on umemcache 0.5
- added support for MAX_ITEM_SIZE

2012-09-07 - 0.2
################

- Added the licence info

2012-08-28 - 0.1
################

- Initial release
